@@ -57,7 +57,7 @@ pub mod components {
 #[allow(unused_assignments, unused_imports, unused_variables)]
 pub mod server {
 
-use actix_web::{web::*, Responder, HttpResponse, HttpResponseBuilder, http::StatusCode, error::InternalError};
+use actix_web::{web::*, HttpRequest, HttpResponse, Responder, HttpResponseBuilder, http::StatusCode, error::InternalError};
 use async_trait::async_trait;
 use serde::{Deserialize, Serialize};
 
@@ -86,7 +86,7 @@ pub struct PayloadRawParts {
 {{~#*inline "auth_fn_trait"}}
     async fn {{snakecase key}}(
         &self,
-        request: &actix_web::HttpRequest,
+        request: &HttpRequest,
         payload: &PayloadRawParts,
     ) -> Result<Self::AuthorizedData, Self::Error>;
 {{~/inline}}
@@ -97,7 +97,7 @@ pub trait {{camelcase info.title}} {
     type AuthorizedData;
     {{~/if}}
     type Error: std::error::Error;
-    type HandlerResult: Into<actix_web::body::AnyBody>;
+    type HandlerResult: Serialize;
 
     fn handle_error<E: std::error::Error>(req: &HttpRequest, e: &E) -> Self::HandlerResult;
 
@@ -121,7 +121,7 @@ pub trait {{camelcase info.title}} {
 {{#if summary}}/// {{summary}}{{/if}}
 {{~#if description}}/// {{description}}{{/if}}
 async fn {{snakecase operationId}}<Server: {{camelcase title}}>(
-    request: actix_web::HttpRequest,
+    request: HttpRequest,
     server: Data<Server>,{{!-- {{~#if parameters}} --}}
     {{~#if (has parameters "in" "query")~}}
     query: Query<super::{{snakecase operationId}}::Query>,
@@ -163,7 +163,7 @@ async fn {{snakecase operationId}}<Server: {{camelcase title}}>(
                 {{~/with}}
             )
             {{~/if}}
-            .body(<Server as {{camelcase ../title}}>::handle_error(&request, &err)),
+            .json(<Server as {{camelcase ../title}}>::handle_error(&request, &err)),
     };
 
     {{~#unless noBody}}
@@ -175,7 +175,7 @@ async fn {{snakecase operationId}}<Server: {{camelcase title}}>(
                     Ok(body) => body,
                     Err(e) => return HttpResponse::BadRequest()
                         .content_type("application/json")
-                        .body(<Server as {{camelcase ../title}}>::handle_error(&request, &e)),
+                        .json(<Server as {{camelcase ../title}}>::handle_error(&request, &e)),
                 };
             {{~/with}}
 
@@ -185,7 +185,7 @@ async fn {{snakecase operationId}}<Server: {{camelcase title}}>(
                     Ok(body) => body,
                     Err(e) => return HttpResponse::BadRequest()
                         .content_type("application/x-www-form-urlencoded")
-                        .body(<Server as {{camelcase ../title}}>::handle_error(&request, &e)),
+                        .json(<Server as {{camelcase ../title}}>::handle_error(&request, &e)),
                 };
             {{~/with}}
 
@@ -238,7 +238,7 @@ async fn {{snakecase operationId}}<Server: {{camelcase title}}>(
                     Ok(auth_data) => auth_data,
                     Err(e) => return HttpResponse::Unauthorized()
                         .content_type("application/json")
-                        .body(<Server as {{camelcase ../../title}}>::handle_error(&request, &e)),
+                        .json(<Server as {{camelcase ../../title}}>::handle_error(&request, &e)),
                 };
             {{~/each}}
         {{~/each}}
@@ -292,7 +292,7 @@ async fn {{snakecase operationId}}<Server: {{camelcase title}}>(
         Err(Error::Unknown(err)) =>
             HttpResponse::Unauthorized()
                 .content_type("application/json")
-                .body(<Server as {{camelcase title}}>::handle_error(&request, &err)),
+                .json(<Server as {{camelcase title}}>::handle_error(&request, &err)),
     }
 }
 {{~/inline}}
